pyrcmip
=======

.. sec-begin-links

+-------------------+-----------+
| Repository health | |License| |
+-------------------+-----------+

+-----------------+------------------+
| Latest releases | |Latest Version| |
+-----------------+------------------+

+-----------------+----------------+---------------+
| Latest activity | |Contributors| | |Last Commit| |
+-----------------+----------------+---------------+

.. |License| image:: https://img.shields.io/github/license/rcmip/pyrcmip.svg
    :target: https://gitlab.com/rcmip/pyrcmip/blob/master/LICENSE
.. |Latest Version| image:: https://img.shields.io/gitlab/tag/rcmip/pyrcmip.svg
    :target: https://gitlab.com/rcmip/pyrcmip/releases
.. |Last Commit| image:: https://img.shields.io/gitlab/last-commit/rcmip/pyrcmip.svg
    :target: https://gitlab.com/rcmip/pyrcmip/commits/master
.. |Contributors| image:: https://img.shields.io/github/contributors/rcmip/pyrcmip.svg
    :target: https://gitlab.com/rcmip/pyrcmip/graphs/contributors

.. sec-begin-index

pyrcmip is a tool for validating and uploading results to [RCMIP](http://rcmip.org).  Reduced Complexity Model Intercomparison Project (RCMIP)
is a project to test the ability of  reduced-complexity, simple climate models to emuate a range of CMIP6 coupled models.


.. sec-end-index

Installation
------------

The easiest way to install pyrcmip is with `pip <https://pypi.org/project/pip/>`_

::

  # if you're using a virtual environment, make sure you're in it
  pip install pyrcmip


Documentation
-------------

Documentation to come in future


Contributing
------------

If you'd like to contribute, please make a pull request!
The pull request templates should ensure that you provide all the necessary information.

.. sec-begin-license

License
-------

pyrcmip is free software under a BSD 3-Clause License, see `LICENSE <https://gitlab.com/rcmip/pyrcmip/blob/master/LICENSE>`_. If you
make use of pyrcmip or any of the RCMIP project, please cite:

.. code-block::

    Nicholls, Z. R. J., Meinshausen, M., Lewis, J., Gieseke, R., Dommenget, D., Dorheim, K., Fan, C.-S., Fuglestvedt, J. S., Gasser, T., Golüke, U., Goodwin, P., Kriegler, E., Leach, N. J., Marchegiani, D., Quilcaille, Y., Samset, B. H., Sandstad, M., Shiklomanov, A. N., Skeie, R. B., Smith, C. J., Tanaka, K., Tsutsui, J., and Xie, Z.: Reduced complexity model intercomparison project phase 1: Protocol, results and initial observations, Geosci. Model Dev. Discuss., https://doi.org/10.5194/gmd-2019-375, 2020.

.. sec-end-license